madcc: Useful cryptocurrency tools
==================================

.. image:: https://pypip.in/v/madcc/badge.png
  :target: https://pypi.python.org/pypi/madcc
  :alt: PyPI package version
.. image:: https://travis-ci.org/madeddie/madcc.svg?branch=master
  :target: https://travis-ci.org/madeddie/madcc
  :alt: Travis build status
.. image:: https://img.shields.io/coveralls/github/madeddie/madcc.svg
  :target: https://coveralls.io/github/madeddie/madcc
  :alt: Coveralls code coverage
.. image:: https://codecov.io/gh/madeddie/madcc/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/madeddie/madcc
  :alt: Codecov code coverage
.. image:: https://requires.io/github/madeddie/madcc/requirements.svg?branch=master
  :target: https://requires.io/github/madeddie/madcc/requirements/?branch=master
  :alt: Requirements Status

A collection of useful cryptocurrency utils and functions. Makes use of:

- `kraken API <https://www.kraken.com/help/api>`
- `krakenex <https://github.com/veox/python3-krakenex>`.

----

Included functions:

- None (yet)

Scripts:

- kraken_limits - Used to show the current withdraw and deposit limits on Kraken.
- crypto_assers - Look up value of a list of crypto assets defined in a txt file.
